@@ -84,7 +84,7 @@
 #define PLASMA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PLASMA_NO_DEPRECATED
-#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef PLASMA_NO_DEPRECATED_WARNINGS
 #  define PLASMA_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PLASMA_DEPRECATED_WARNINGS_SINCE PLASMA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define PLASMA_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
